/* 
 * Copyright 2009 IT Mill Ltd.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.vaadin.demo.mobilemail;

import com.vaadin.addon.touchkit.ui.EmailField;
import com.vaadin.addon.touchkit.ui.NavigationView;
import com.vaadin.addon.touchkit.ui.VerticalComponentGroup;
import com.vaadin.annotations.*;
import com.vaadin.server.Page;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinSession;
import com.vaadin.server.WebBrowser;
import com.vaadin.shared.communication.PushMode;
import com.vaadin.ui.CssLayout;
import com.vaadin.ui.UI;

@SuppressWarnings("serial")
@Theme("mobilemail")
@Title("Vaadin Mail Demo")
@Widgetset("com.vaadin.demo.mobilemail.gwt.MobileMailWidgetSet")
@Push(PushMode.AUTOMATIC)
@PreserveOnRefresh
public class MobileMailUI extends UI {

    public MobileMailUI() {
    }

    @SuppressWarnings("deprecation")
    public WebBrowser getBrowser() {
        VaadinSession context = UI.getCurrent().getSession();
        return context.getBrowser();
    }

    @Override
    protected void init(VaadinRequest request) {
        setContent(new MainView().build());
        setImmediate(true);
    }

    class MainView extends NavigationView implements Page.BrowserWindowResizeListener {

        CssLayout layout = new CssLayout();
        VerticalComponentGroup componentGroup = new VerticalComponentGroup();
        boolean lastOrientationHorizontal;

        NavigationView build() {
            setWidth("100%");
            setHeight("100%");
            EmailField emailField = new EmailField("test");
            componentGroup.addComponent(emailField);
            layout.addComponent(componentGroup);
            setContent(layout);
            return this;
        }

        @Override
        public void attach() {
            lastOrientationHorizontal = isHorizontal();
            if (Page.getCurrent() != null) {
                Page.getCurrent().addBrowserWindowResizeListener(this);
            }
        }

        void setOrientation() {
            layout.removeAllComponents();
            layout.addComponent(componentGroup);
            lastOrientationHorizontal = isHorizontal();
        }

        boolean isHorizontal() {
            int width = 0, height = 0;
            if (Page.getCurrent() != null) {
                width = Page.getCurrent().getBrowserWindowWidth();
                height = Page.getCurrent().getBrowserWindowHeight();
            }
            return (width > height);

        }

        public void browserWindowResized(Page.BrowserWindowResizeEvent browserWindowResizeEvent) {
            if (getUI() != null) {
                if (isHorizontal() != lastOrientationHorizontal) {
                    setOrientation();
                }
            }
        }
    }
}
